@@ -68,6 +68,8 @@ from .cloudbuild import (
     UpdateBuildTriggerRequest,
     UpdateWorkerPoolOperationMetadata,
     UpdateWorkerPoolRequest,
+    UploadedMavenArtifact,
+    UploadedPythonPackage,
     Volume,
     WebhookConfig,
     WorkerPool,
@@ -128,6 +130,8 @@ __all__ = (
     "UpdateBuildTriggerRequest",
     "UpdateWorkerPoolOperationMetadata",
     "UpdateWorkerPoolRequest",
+    "UploadedMavenArtifact",
+    "UploadedPythonPackage",
     "Volume",
     "WebhookConfig",
     "WorkerPool",
