@@ -35,7 +35,7 @@ from google.longrunning import operations_pb2
 from requests import __version__ as requests_version
 import dataclasses
 import re
-from typing import Callable, Dict, List, Optional, Sequence, Tuple, Union
+from typing import Any, Callable, Dict, List, Optional, Sequence, Tuple, Union
 import warnings
 
 try:
@@ -490,7 +490,7 @@ class RepositoryManagerRestInterceptor:
         self,
         request: iam_policy_pb2.GetIamPolicyRequest,
         metadata: Sequence[Tuple[str, str]],
-    ) -> policy_pb2.Policy:
+    ) -> Tuple[iam_policy_pb2.GetIamPolicyRequest, Sequence[Tuple[str, str]]]:
         """Pre-rpc interceptor for get_iam_policy
 
         Override in a subclass to manipulate the request or metadata
@@ -498,9 +498,7 @@ class RepositoryManagerRestInterceptor:
         """
         return request, metadata
 
-    def post_get_iam_policy(
-        self, response: iam_policy_pb2.GetIamPolicyRequest
-    ) -> policy_pb2.Policy:
+    def post_get_iam_policy(self, response: policy_pb2.Policy) -> policy_pb2.Policy:
         """Post-rpc interceptor for get_iam_policy
 
         Override in a subclass to manipulate the response
@@ -513,7 +511,7 @@ class RepositoryManagerRestInterceptor:
         self,
         request: iam_policy_pb2.SetIamPolicyRequest,
         metadata: Sequence[Tuple[str, str]],
-    ) -> policy_pb2.Policy:
+    ) -> Tuple[iam_policy_pb2.SetIamPolicyRequest, Sequence[Tuple[str, str]]]:
         """Pre-rpc interceptor for set_iam_policy
 
         Override in a subclass to manipulate the request or metadata
@@ -521,9 +519,7 @@ class RepositoryManagerRestInterceptor:
         """
         return request, metadata
 
-    def post_set_iam_policy(
-        self, response: iam_policy_pb2.SetIamPolicyRequest
-    ) -> policy_pb2.Policy:
+    def post_set_iam_policy(self, response: policy_pb2.Policy) -> policy_pb2.Policy:
         """Post-rpc interceptor for set_iam_policy
 
         Override in a subclass to manipulate the response
@@ -536,7 +532,7 @@ class RepositoryManagerRestInterceptor:
         self,
         request: iam_policy_pb2.TestIamPermissionsRequest,
         metadata: Sequence[Tuple[str, str]],
-    ) -> iam_policy_pb2.TestIamPermissionsResponse:
+    ) -> Tuple[iam_policy_pb2.TestIamPermissionsRequest, Sequence[Tuple[str, str]]]:
         """Pre-rpc interceptor for test_iam_permissions
 
         Override in a subclass to manipulate the request or metadata
@@ -545,7 +541,7 @@ class RepositoryManagerRestInterceptor:
         return request, metadata
 
     def post_test_iam_permissions(
-        self, response: iam_policy_pb2.TestIamPermissionsRequest
+        self, response: iam_policy_pb2.TestIamPermissionsResponse
     ) -> iam_policy_pb2.TestIamPermissionsResponse:
         """Post-rpc interceptor for test_iam_permissions
 
@@ -559,7 +555,7 @@ class RepositoryManagerRestInterceptor:
         self,
         request: operations_pb2.CancelOperationRequest,
         metadata: Sequence[Tuple[str, str]],
-    ) -> None:
+    ) -> Tuple[operations_pb2.CancelOperationRequest, Sequence[Tuple[str, str]]]:
         """Pre-rpc interceptor for cancel_operation
 
         Override in a subclass to manipulate the request or metadata
@@ -567,9 +563,7 @@ class RepositoryManagerRestInterceptor:
         """
         return request, metadata
 
-    def post_cancel_operation(
-        self, response: operations_pb2.CancelOperationRequest
-    ) -> None:
+    def post_cancel_operation(self, response: None) -> None:
         """Post-rpc interceptor for cancel_operation
 
         Override in a subclass to manipulate the response
@@ -582,7 +576,7 @@ class RepositoryManagerRestInterceptor:
         self,
         request: operations_pb2.GetOperationRequest,
         metadata: Sequence[Tuple[str, str]],
-    ) -> operations_pb2.Operation:
+    ) -> Tuple[operations_pb2.GetOperationRequest, Sequence[Tuple[str, str]]]:
         """Pre-rpc interceptor for get_operation
 
         Override in a subclass to manipulate the request or metadata
@@ -591,7 +585,7 @@ class RepositoryManagerRestInterceptor:
         return request, metadata
 
     def post_get_operation(
-        self, response: operations_pb2.GetOperationRequest
+        self, response: operations_pb2.Operation
     ) -> operations_pb2.Operation:
         """Post-rpc interceptor for get_operation
 
@@ -744,7 +738,7 @@ class RepositoryManagerRestTransport(RepositoryManagerTransport):
         def __hash__(self):
             return hash("BatchCreateRepositories")
 
-        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, str] = {}
+        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, Any] = {}
 
         @classmethod
         def _get_unset_required_fields(cls, message_dict):
@@ -768,7 +762,6 @@ class RepositoryManagerRestTransport(RepositoryManagerTransport):
                 request (~.repositories.BatchCreateRepositoriesRequest):
                     The request object. Message for creating repositoritories
                 in batch.
-
                 retry (google.api_core.retry.Retry): Designation of what errors, if any,
                     should be retried.
                 timeout (float): The timeout for this request.
@@ -844,7 +837,7 @@ class RepositoryManagerRestTransport(RepositoryManagerTransport):
         def __hash__(self):
             return hash("CreateConnection")
 
-        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, str] = {
+        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, Any] = {
             "connectionId": "",
         }
 
@@ -944,7 +937,7 @@ class RepositoryManagerRestTransport(RepositoryManagerTransport):
         def __hash__(self):
             return hash("CreateRepository")
 
-        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, str] = {
+        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, Any] = {
             "repositoryId": "",
         }
 
@@ -1044,7 +1037,7 @@ class RepositoryManagerRestTransport(RepositoryManagerTransport):
         def __hash__(self):
             return hash("DeleteConnection")
 
-        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, str] = {}
+        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, Any] = {}
 
         @classmethod
         def _get_unset_required_fields(cls, message_dict):
@@ -1133,7 +1126,7 @@ class RepositoryManagerRestTransport(RepositoryManagerTransport):
         def __hash__(self):
             return hash("DeleteRepository")
 
-        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, str] = {}
+        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, Any] = {}
 
         @classmethod
         def _get_unset_required_fields(cls, message_dict):
@@ -1222,7 +1215,7 @@ class RepositoryManagerRestTransport(RepositoryManagerTransport):
         def __hash__(self):
             return hash("FetchLinkableRepositories")
 
-        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, str] = {}
+        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, Any] = {}
 
         @classmethod
         def _get_unset_required_fields(cls, message_dict):
@@ -1247,7 +1240,6 @@ class RepositoryManagerRestTransport(RepositoryManagerTransport):
                     request (~.repositories.FetchLinkableRepositoriesRequest):
                         The request object. Request message for
                     FetchLinkableRepositories.
-
                     retry (google.api_core.retry.Retry): Designation of what errors, if any,
                         should be retried.
                     timeout (float): The timeout for this request.
@@ -1315,7 +1307,7 @@ class RepositoryManagerRestTransport(RepositoryManagerTransport):
         def __hash__(self):
             return hash("FetchReadToken")
 
-        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, str] = {}
+        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, Any] = {}
 
         @classmethod
         def _get_unset_required_fields(cls, message_dict):
@@ -1414,7 +1406,7 @@ class RepositoryManagerRestTransport(RepositoryManagerTransport):
         def __hash__(self):
             return hash("FetchReadWriteToken")
 
-        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, str] = {}
+        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, Any] = {}
 
         @classmethod
         def _get_unset_required_fields(cls, message_dict):
@@ -1438,7 +1430,6 @@ class RepositoryManagerRestTransport(RepositoryManagerTransport):
                 request (~.repositories.FetchReadWriteTokenRequest):
                     The request object. Message for fetching SCM read/write
                 token.
-
                 retry (google.api_core.retry.Retry): Designation of what errors, if any,
                     should be retried.
                 timeout (float): The timeout for this request.
@@ -1515,7 +1506,7 @@ class RepositoryManagerRestTransport(RepositoryManagerTransport):
         def __hash__(self):
             return hash("GetConnection")
 
-        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, str] = {}
+        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, Any] = {}
 
         @classmethod
         def _get_unset_required_fields(cls, message_dict):
@@ -1539,7 +1530,6 @@ class RepositoryManagerRestTransport(RepositoryManagerTransport):
                 request (~.repositories.GetConnectionRequest):
                     The request object. Message for getting the details of a
                 Connection.
-
                 retry (google.api_core.retry.Retry): Designation of what errors, if any,
                     should be retried.
                 timeout (float): The timeout for this request.
@@ -1606,7 +1596,7 @@ class RepositoryManagerRestTransport(RepositoryManagerTransport):
         def __hash__(self):
             return hash("GetRepository")
 
-        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, str] = {}
+        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, Any] = {}
 
         @classmethod
         def _get_unset_required_fields(cls, message_dict):
@@ -1630,7 +1620,6 @@ class RepositoryManagerRestTransport(RepositoryManagerTransport):
                 request (~.repositories.GetRepositoryRequest):
                     The request object. Message for getting the details of a
                 Repository.
-
                 retry (google.api_core.retry.Retry): Designation of what errors, if any,
                     should be retried.
                 timeout (float): The timeout for this request.
@@ -1696,7 +1685,7 @@ class RepositoryManagerRestTransport(RepositoryManagerTransport):
         def __hash__(self):
             return hash("ListConnections")
 
-        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, str] = {}
+        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, Any] = {}
 
         @classmethod
         def _get_unset_required_fields(cls, message_dict):
@@ -1720,7 +1709,6 @@ class RepositoryManagerRestTransport(RepositoryManagerTransport):
                 request (~.repositories.ListConnectionsRequest):
                     The request object. Message for requesting list of
                 Connections.
-
                 retry (google.api_core.retry.Retry): Designation of what errors, if any,
                     should be retried.
                 timeout (float): The timeout for this request.
@@ -1788,7 +1776,7 @@ class RepositoryManagerRestTransport(RepositoryManagerTransport):
         def __hash__(self):
             return hash("ListRepositories")
 
-        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, str] = {}
+        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, Any] = {}
 
         @classmethod
         def _get_unset_required_fields(cls, message_dict):
@@ -1812,7 +1800,6 @@ class RepositoryManagerRestTransport(RepositoryManagerTransport):
                 request (~.repositories.ListRepositoriesRequest):
                     The request object. Message for requesting list of
                 Repositories.
-
                 retry (google.api_core.retry.Retry): Designation of what errors, if any,
                     should be retried.
                 timeout (float): The timeout for this request.
@@ -1880,7 +1867,7 @@ class RepositoryManagerRestTransport(RepositoryManagerTransport):
         def __hash__(self):
             return hash("UpdateConnection")
 
-        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, str] = {}
+        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, Any] = {}
 
         @classmethod
         def _get_unset_required_fields(cls, message_dict):
